@@ -1,6 +1,3 @@
-import logging
-logger = logging.getLogger(__name__)
-
 from .utils import Msg
 from .utils import RunEngineInterrupted
 from .utils import IllegalMessageSequence
@@ -8,6 +5,7 @@ from .utils import FailedStatus
 
 from .run_engine import RunEngine
 from .preprocessors import SupplementalData
+from .log import set_handler
 
 from ._version import get_versions
 __version__ = get_versions()['version']
