@@ -6,15 +6,11 @@ from bluesky.object_plans import AbsScanPlan
 from bluesky.preprocessors import run_wrapper, subs_wrapper
 from bluesky.plan_stubs import pause
 import bluesky.plans as bp
-from bluesky.callbacks import (CallbackCounter, LiveTable, LiveFit,
-                               LiveFitPlot, LivePlot, LiveGrid, LiveScatter)
-from bluesky.callbacks import LiveMesh, LiveRaster  # deprecated but tested
+from bluesky.callbacks import CallbackCounter, LiveTable, LiveFit
+from bluesky.callbacks.mpl_plotting import (LiveScatter, LivePlot, LiveGrid,
+                                            LiveFitPlot, LiveRaster, LiveMesh)
 from bluesky.callbacks.broker import BrokerCallbackBase
-from bluesky.callbacks import CallbackBase
 from bluesky.tests.utils import _print_redirect, MsgCollector, DocCollector
-import signal
-import threading
-import time
 import pytest
 import numpy as np
 import matplotlib.pyplot as plt
@@ -131,12 +127,16 @@ def test_table(RE, hw):
     with _print_redirect() as fout:
         hw.det.precision = 2
         hw.motor.precision = 2
+        hw.motor.setpoint.put(0.0)  # Make dtype 'number' not 'integer'.
+        hw.det.put(0.0)  # Make dtype 'number' not 'integer'.
         assert hw.det.describe()['det']['precision'] == 2
         assert hw.motor.describe()['motor']['precision'] == 2
+        assert hw.det.describe()['det']['dtype'] == 'number'
+        assert hw.motor.describe()['motor']['dtype'] == 'number'
 
         table = LiveTable(['det', 'motor'], min_width=16, extra_pad=2)
         ad_scan = bp.adaptive_scan([hw.det], 'det', hw.motor,
-                                   -15, 5, .01, 1, .05,
+                                   -15.0, 5., .01, 1, .05,
                                    True)
         # use lossless sub here because rows can get dropped
         token = RE.subscribe(table)
@@ -298,6 +298,21 @@ def test_live_fit_multidim(RE, hw):
         assert np.allclose(cb.result.values[k], v, atol=1e-6)
 
 
+def test_live_plot_from_callbacks():
+    import bluesky.callbacks.core
+    # We don't want the shims in callbacks.core, see #1133 for discussion
+    assert not hasattr(bluesky.callbacks.core, 'LivePlot')
+    # We still want the shims in callbacks.__init__
+    from bluesky.callbacks import LivePlot as LivePlotFromCallbacks
+    assert LivePlotFromCallbacks is LivePlot
+
+    # Make sure we can subclass it
+    class FromCallbacks(LivePlotFromCallbacks):
+        ...
+
+    FromCallbacks('det', 'motor')
+
+
 def test_live_fit_plot(RE, hw):
     try:
         import lmfit
