@@ -35,7 +35,7 @@ def test_verbose(RE, hw):
     RE.verbose = True
     assert RE.verbose
     # Emit all four kinds of document, exercising the logging.
-    RE([Msg('open_run'), Msg('create'), Msg('read', hw.det), Msg('save'),
+    RE([Msg('open_run'), Msg('create', name='primary'), Msg('read', hw.det), Msg('save'),
         Msg('close_run')])
 
 
@@ -136,6 +136,16 @@ def test_stop_motors_and_log_any_errors(RE, hw):
     RE.stop()
 
 
+@requires_ophyd
+def test_flyer_with_collect_asset_documents(RE):
+
+    from ophyd.sim import det, new_trivial_flyer, trivial_flyer
+    from bluesky.preprocessors import fly_during_wrapper
+    assert hasattr(new_trivial_flyer, 'collect_asset_docs')
+    assert hasattr(trivial_flyer, 'collec_asset_docs') == False
+    RE(fly_during_wrapper(count([det], num=5), [new_trivial_flyer, trivial_flyer]))
+
+
 @requires_ophyd
 def test_collect_uncollected_and_log_any_errors(RE):
     # test that if stopping one motor raises an error, we can carry on
@@ -222,12 +232,12 @@ def test_dropping_without_an_open_bundle_is_illegal(RE):
 
 def test_opening_a_bundle_without_a_run_is_illegal(RE):
     with pytest.raises(IllegalMessageSequence):
-        RE([Msg('create')])
+        RE([Msg('create', name='primary')])
 
 
 def test_checkpoint_inside_a_bundle_is_illegal(RE):
     with pytest.raises(IllegalMessageSequence):
-        RE([Msg('open_run'), Msg('create'), Msg('checkpoint')])
+        RE([Msg('open_run'), Msg('create', name='primary'), Msg('checkpoint')])
 
 
 def test_redundant_monitors_are_illegal(RE):
@@ -308,14 +318,14 @@ def test_empty_bundle(RE, hw):
 
     # In this case, an Event should be emitted.
     mutable.clear()
-    RE([Msg('open_run'), Msg('create'), Msg('read', hw.det), Msg('save')],
+    RE([Msg('open_run'), Msg('create', name='primary'), Msg('read', hw.det), Msg('save')],
        {'event': cb})
     assert 'flag' in mutable
 
     # In this case, an Event should not be emitted because the bundle is
     # emtpy (i.e., there are no readings.)
     mutable.clear()
-    RE([Msg('open_run'), Msg('create'), Msg('save')], {'event': cb})
+    RE([Msg('open_run'), Msg('create', name='primary'), Msg('save')], {'event': cb})
     assert 'flag' not in mutable
 
 
@@ -1086,7 +1096,7 @@ def test_bad_from_idle_transitions(RE, change_func):
 def test_empty_cache_pause(RE):
     RE.rewindable = False
     pln = [Msg('open_run'),
-           Msg('create'),
+           Msg('create', name='primary'),
            Msg('pause'),
            Msg('save'),
            Msg('close_run')]
@@ -1406,7 +1416,7 @@ def test_drop(RE, hw):
     det = hw.det
 
     def inner(msg):
-        yield Msg('create')
+        yield Msg('create', name='primary')
         yield Msg('read', det)
         yield Msg(msg)
 
@@ -1445,11 +1455,11 @@ def test_failing_describe_callback(RE, hw):
     def plan():
         yield Msg('open_run')
         try:
-            yield Msg('create')
+            yield Msg('create', name='primary')
             yield Msg('read', det)
             yield Msg('save')
         finally:
-            yield Msg('create')
+            yield Msg('create', name='primary')
             yield Msg('read', det2)
             yield Msg('save')
         yield Msg('close_run')
