@@ -33,10 +33,13 @@ def approx_multi_traj_checker(RE, scan, expected_data, *, decimal=2):
 
     RE(scan, {'event': collect_data})
     keys = sorted(expected_data[0].keys())
+
     actual_values = [[row[key] for key in keys]
                      for row in actual_data]
+
     expected_values = [[row[key] for key in keys]
                        for row in expected_data]
+
     err_msg = 'Trajectory differs. Data keys: {}'.format(', '.join(keys))
     numpy.testing.assert_almost_equal(actual_values, expected_values,
                                       decimal=decimal,
@@ -479,3 +482,118 @@ def test_relative_fermat_spiral(RE, hw):
     approx_multi_traj_checker(RE, scan,
                               _get_fermat_data(start_x, start_y),
                               decimal=2)
+
+
+def test_x2x_scan(RE, hw):
+    y_start = -1
+    y_stop = 4
+    y_num = 11
+    expected_traj = []
+
+    for i in range(y_num):
+        y_val = y_start + i * (y_stop - y_start) / (y_num - 1)
+        expected_traj.append({'motor1': y_val, 'det': 1.0, 'motor2': y_val / 2})
+
+    for d in expected_traj:
+        d.update({'motor1_setpoint': d['motor1']})
+        d.update({'motor2_setpoint': d['motor2']})
+
+    scan = bp.x2x_scan([hw.det], hw.motor1, hw.motor2, y_start, y_stop, y_num )
+
+    multi_traj_checker(RE, scan, expected_traj)
+
+
+square_spiral_data = [
+    {'det': 1.0, 'motor1': 0.0, 'motor2': 0.0},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': 0.0},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': -0.5},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': -0.5},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': -0.5},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': 0.0},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': 0.5},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': 0.5},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': 0.5},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': 0.5},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': 0.0},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': -0.5},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': -1.0},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': -1.0},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': -1.0},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': -1.0},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': -1.0},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': -0.5},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': 0.0},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': 0.5},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': 1.0},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': 1.0},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': 1.0},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': 1.0},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': 1.0},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': 1.0},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': 0.5},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': 0.0},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': -0.5},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': -1.0},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': -1.5},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': -1.5},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': -1.5},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': -1.5},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': -1.5},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': -1.5},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': -1.5},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': -1.0},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': -0.5},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': 0.0},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': 0.5},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': 1.0},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': 1.5},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': 1.5},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': 1.5},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': 1.5},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': 1.5},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': 1.5},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': 1.5},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': -2.0},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': -2.0},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': -2.0},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': -2.0},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': -2.0},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': -2.0},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': -2.0},
+    {'det': 1.0, 'motor1': -1.5, 'motor2': 2.0},
+    {'det': 1.0, 'motor1': -1.0, 'motor2': 2.0},
+    {'det': 1.0, 'motor1': -0.5, 'motor2': 2.0},
+    {'det': 1.0, 'motor1': 0.0, 'motor2': 2.0},
+    {'det': 1.0, 'motor1': 0.5, 'motor2': 2.0},
+    {'det': 1.0, 'motor1': 1.0, 'motor2': 2.0},
+    {'det': 1.0, 'motor1': 1.5, 'motor2': 2.0},
+]
+
+
+def test_spiral_square(RE, hw):
+    motor1 = hw.motor1
+    motor2 = hw.motor2
+    det = hw.det
+
+    plan = bp.spiral_square(
+        [det], motor1, motor2,
+        x_center=0, y_center=0,
+        x_range=3, y_range=4,
+        x_num=3*2+1, y_num=4*2+1)
+
+    approx_multi_traj_checker(RE, plan,
+                              square_spiral_data, decimal=2)
+                              
+
+def test_rel_spiral_square(RE, hw):
+    motor1 = hw.motor1
+    motor2 = hw.motor2
+    det = hw.det
+
+    plan = bp.rel_spiral_square(
+        [det], motor1, motor2,
+        x_range=3, y_range=4,
+        x_num=3*2+1, y_num=4*2+1)
+
+    approx_multi_traj_checker(RE, plan,
+                              square_spiral_data, decimal=2)
